@@ -26,7 +26,7 @@ copyright = '2020, Mark Taylor'
 author = 'Mark Taylor'
 
 # The full version, including alpha/beta/rc tags
-release = '0.0.6'
+release = '0.1.0'
 
 
 # -- General configuration ---------------------------------------------------
@@ -58,7 +58,7 @@ templates_path = ['_templates']
 # directories to ignore when looking for source files.
 # This pattern also affects html_static_path and html_extra_path.
 exclude_patterns = [
-    'project.md', 'tests', 'src',
+    'tests', 'src',
     '.tox',
     '.pytest_cache',
     '_build', 'Thumbs.db', '.DS_Store'
