@@ -40,3 +40,21 @@ window 6
 defenestrate 12
 """
     line_by_line_compare_exact(a=expected_str, b=capsys.readouterr().out)
+
+
+def session_00001_line_72():
+    r"""
+    >>> print('Greetings Planet!')
+    Greetings Planet!
+    """
+
+
+def test_code_80_output_86(capsys):
+    from datetime import date
+    d = date.fromordinal(730920)    # 730920th day after 1. 1. 0001
+    print(d)
+
+    expected_str = """\
+2002-03-11
+"""
+    line_by_line_compare_exact(a=expected_str, b=capsys.readouterr().out)
