@@ -141,7 +141,7 @@ def test_code_does_not_print_fails():
     )
     simulator_status = phmdoctest.simulator.run_and_pytest(
         well_formed_command=command,
-        pytest_options=['--strict', '-v']
+        pytest_options=['--strict', '--doctest-modules', '-v']
     )
     assert simulator_status.runner_status.exit_code == 0
     assert simulator_status.pytest_exit_code == 1
@@ -154,7 +154,7 @@ def test_more_printed_than_expected_fails():
     )
     simulator_status = phmdoctest.simulator.run_and_pytest(
         well_formed_command=command,
-        pytest_options=['--strict', '-v']
+        pytest_options=['--strict', '--doctest-modules', '-v']
     )
     assert simulator_status.runner_status.exit_code == 0
     assert simulator_status.pytest_exit_code == 1
@@ -167,7 +167,7 @@ def test_more_expected_than_printed_fails():
     )
     simulator_status = phmdoctest.simulator.run_and_pytest(
         well_formed_command=command,
-        pytest_options=['--strict', '-v']
+        pytest_options=['--strict', '--doctest-modules', '-v']
     )
     assert simulator_status.runner_status.exit_code == 0
     assert simulator_status.pytest_exit_code == 1
@@ -181,7 +181,7 @@ def test_skip_same_block_twice():
     )
     simulator_status = phmdoctest.simulator.run_and_pytest(
         well_formed_command=command,
-        pytest_options=['--strict', '-v']
+        pytest_options=['--strict', '--doctest-modules', '-v']
     )
     assert simulator_status.runner_status.exit_code == 0
     assert simulator_status.pytest_exit_code == 0
@@ -193,13 +193,52 @@ def test_pytest_really_fails():
     Generate a pytest that will assert.
     """
     simulator_status = verify.one_example(
-        'phmdoctest tests/unexpected_output.md --outfile test_unexpected_output.py',
+        'phmdoctest tests/unexpected_output.md --outfile discarded.py',
         want_file_name=None,
-        pytest_options=['--strict', '-v']
+        pytest_options=['--strict', '--doctest-modules', '-v']
     )
     assert simulator_status.pytest_exit_code == 1
 
 
+def test_pytest_session_fails():
+    """Make sure pytest fails due to incorrect session output in the .md file.
+
+    Generate a pytest that fails pytest.
+    """
+    simulator_status = verify.one_example(
+        'phmdoctest tests/bad_session_output.md --outfile discarded.py',
+        want_file_name=None,
+        pytest_options=['--strict', '--doctest-modules', '-v']
+    )
+    assert simulator_status.pytest_exit_code == 1
+
+
+def test_project_md():
+    """Make sure that project.md generates a file that passes pytest."""
+    simulator_status = verify.one_example(
+        'phmdoctest project.md --outfile discarded.py',
+        want_file_name=None,
+        pytest_options=['--strict', '--doctest-modules', '-v']
+    )
+    assert simulator_status.runner_status.exit_code == 0
+    assert simulator_status.pytest_exit_code == 0
+
+
+def test_example2_report():
+    """Check example2_report.txt used in .travis.yml."""
+    simulator_status = verify.one_example(
+        'phmdoctest doc/example2.md --skip "Python 3.7" --skip LAST --report'
+        ' --outfile discarded.py',
+        want_file_name=None,
+        pytest_options=None
+    )
+    assert simulator_status.runner_status.exit_code == 0
+    stdout = simulator_status.runner_status.stdout
+    with open('tests/example2_report.txt', 'r', encoding='utf-8') as f:
+        want = f.read()
+    verify.a_and_b_are_the_same(a=want, b=stdout)
+
+
 def test_def_test_identifier():
     """Painful way to eliminate 2 coverage missed statements."""
     # The function print_capture.test_identifier() is used as
@@ -229,7 +268,7 @@ def test_blanklines_in_output():
     )
     simulator_status = phmdoctest.simulator.run_and_pytest(
         well_formed_command=command,
-        pytest_options=['--strict', '-v']
+        pytest_options=['--strict', '--doctest-modules', '-v']
     )
     assert simulator_status.runner_status.exit_code == 0
     assert simulator_status.pytest_exit_code == 0
@@ -243,12 +282,12 @@ def test_skip_first():
     )
     simulator_status = phmdoctest.simulator.run_and_pytest(
         well_formed_command=command,
-        pytest_options=['--strict', '-v']
+        pytest_options=['--strict', '--doctest-modules', '-v']
     )
     assert simulator_status.runner_status.exit_code == 0
     assert simulator_status.pytest_exit_code == 0
     stdout = simulator_status.runner_status.stdout
-    assert 'py3         9  skip-code    "FIRST"' in stdout
+    assert 'py3         9  skip-code     "FIRST"' in stdout
     assert 'FIRST         9' in stdout
 
 
@@ -260,7 +299,7 @@ def test_skip_second():
     )
     simulator_status = phmdoctest.simulator.run_and_pytest(
         well_formed_command=command,
-        pytest_options=['--strict', '-v']
+        pytest_options=['--strict', '--doctest-modules', '-v']
     )
     assert simulator_status.runner_status.exit_code == 0
     assert simulator_status.pytest_exit_code == 0
@@ -269,15 +308,49 @@ def test_skip_second():
     assert 'SECOND        20' in stdout
 
 
+def test_skip_first_session():
+    """Verify --skip FIRST skips a session block."""
+    command = (
+        'phmdoctest tests/twentysix_session_blocks.md -sFIRST'
+        ' --report --outfile discarded.py'
+    )
+    simulator_status = phmdoctest.simulator.run_and_pytest(
+        well_formed_command=command,
+        pytest_options=['--strict', '--doctest-modules', '-v']
+    )
+    assert simulator_status.runner_status.exit_code == 0
+    assert simulator_status.pytest_exit_code == 0
+    stdout = simulator_status.runner_status.stdout
+    assert 'pycon        3  skip-session  "FIRST"' in stdout
+    assert 'FIRST         3' in stdout
+
+
+def test_skip_second_session():
+    """Verify --skip SECOND skips a session block."""
+    command = (
+        'phmdoctest tests/twentysix_session_blocks.md -sSECOND'
+        ' --report --outfile discarded.py'
+    )
+    simulator_status = phmdoctest.simulator.run_and_pytest(
+        well_formed_command=command,
+        pytest_options=['--strict', '--doctest-modules', '-v']
+    )
+    assert simulator_status.runner_status.exit_code == 0
+    assert simulator_status.pytest_exit_code == 0
+    stdout = simulator_status.runner_status.stdout
+    assert 'py           8  skip-session  "SECOND"' in stdout
+    assert 'SECOND        8' in stdout
+
+
 def test_skip_second_when_only_one():
     """Verify --skip SECOND selects no block when only 1 code block."""
     command = (
-        'phmdoctest doc/example1.md -sFIRST'
+        'phmdoctest tests/one_code_block.md -sFIRST'
         ' --skip SECOND --report --outfile discarded.py'
     )
     simulator_status = phmdoctest.simulator.run_and_pytest(
         well_formed_command=command,
-        pytest_options=['--strict', '-v']
+        pytest_options=['--strict', '--doctest-modules', '-v']
     )
     assert simulator_status.runner_status.exit_code == 0
     assert simulator_status.pytest_exit_code == 0
@@ -293,7 +366,7 @@ def test_skip_second_when_more_than_one():
     )
     simulator_status = phmdoctest.simulator.run_and_pytest(
         well_formed_command=command,
-        pytest_options=['--strict', '-v']
+        pytest_options=['--strict', '--doctest-modules', '-v']
     )
     assert simulator_status.runner_status.exit_code == 0
     assert simulator_status.pytest_exit_code == 0
@@ -310,7 +383,7 @@ def test_skip_code_that_has_no_output_block():
     )
     simulator_status = phmdoctest.simulator.run_and_pytest(
         well_formed_command=command,
-        pytest_options=['--strict', '-v']
+        pytest_options=['--strict', '--doctest-modules', '-v']
     )
     assert simulator_status.runner_status.exit_code == 0
     assert simulator_status.pytest_exit_code == 0
@@ -329,7 +402,7 @@ def test_skip_matches_start_of_contents():
     )
     simulator_status = phmdoctest.simulator.run_and_pytest(
         well_formed_command=command,
-        pytest_options=['--strict', '-vv']
+        pytest_options=['--strict', '--doctest-modules', '-vv']
     )
     assert simulator_status.runner_status.exit_code == 0
     assert simulator_status.pytest_exit_code == 0
@@ -337,8 +410,6 @@ def test_skip_matches_start_of_contents():
     assert 'words =       44' in stdout
 
 
-# words = ['cat', 'window', 'defenestrate']
-
 def test_multiple_skips_report():
     """More than one skip applied to the same Python code block."""
     command = 'phmdoctest doc/example2.md --report -sprint -slen'
@@ -352,6 +423,24 @@ def test_multiple_skips_report():
     assert 'len           44' in stdout
 
 
+def test_one_skip_many_matches():
+    """Every block matches the skip pattern presenting multi-line report."""
+    command = (
+        'phmdoctest tests/twentysix_session_blocks.md'
+        ' --skip=">>>" --report'
+    )
+    simulator_status = phmdoctest.simulator.run_and_pytest(
+        well_formed_command=command,
+        pytest_options=None
+    )
+    assert simulator_status.runner_status.exit_code == 0
+    stdout = simulator_status.runner_status.stdout
+
+    with open('tests/twentysix_report.txt', 'r', encoding='utf-8') as f:
+        want = f.read()
+    verify.a_and_b_are_the_same(want, stdout)
+
+
 def test_no_blocks_left_to_test_passing():
     """Generate a pytest file that passes when no blocks to test."""
     command = (
@@ -360,7 +449,7 @@ def test_no_blocks_left_to_test_passing():
     )
     simulator_status = phmdoctest.simulator.run_and_pytest(
         well_formed_command=command,
-        pytest_options=['--strict', '-v']
+        pytest_options=['--strict', '--doctest-modules', '-v']
     )
     assert simulator_status.runner_status.exit_code == 0
     assert simulator_status.pytest_exit_code == 0
@@ -375,7 +464,7 @@ def test_no_blocks_left_to_test_fails():
     )
     simulator_status = phmdoctest.simulator.run_and_pytest(
         well_formed_command=command,
-        pytest_options=['--strict', '-v']
+        pytest_options=['--strict', '--doctest-modules', '-v']
     )
     assert simulator_status.runner_status.exit_code == 0
     assert simulator_status.pytest_exit_code == 1    # pytest failed
@@ -390,7 +479,7 @@ def test_no_code_blocks():
     )
     simulator_status = phmdoctest.simulator.run_and_pytest(
         well_formed_command=command,
-        pytest_options=['--strict', '-v']
+        pytest_options=['--strict', '--doctest-modules', '-v']
     )
     assert simulator_status.runner_status.exit_code == 0
     assert simulator_status.pytest_exit_code == 0
@@ -402,7 +491,7 @@ def test_missing_markdown_file():
     command = 'phmdoctest tests/bogus.md --outfile discarded.py'
     simulator_status = phmdoctest.simulator.run_and_pytest(
         well_formed_command=command,
-        pytest_options=['--strict', '-v']
+        pytest_options=['--strict', '--doctest-modules', '-v']
     )
     assert (
         simulator_status.runner_status.exit_code ==
@@ -417,7 +506,7 @@ def test_bad_usage_option():
     command = 'phmdoctest doc/example1.md --troper --outfile discarded.py'
     simulator_status = phmdoctest.simulator.run_and_pytest(
         well_formed_command=command,
-        pytest_options=['--strict', '-v']
+        pytest_options=['--strict', '--doctest-modules', '-v']
     )
     assert (
         simulator_status.runner_status.exit_code == click.UsageError.exit_code
